Struct Resetreas
#[repr(transparent)]pub struct Resetreas(pub u32);Expand description
Reset reason.
Tuple Fields
0: u32Implementations
impl Resetreas
impl Resetreas
pub const fn set_resetpin(&mut self, val: bool)
pub const fn set_resetpin(&mut self, val: bool)
Reset from pin reset detected.
pub const fn set_ctrlap(&mut self, val: bool)
pub const fn set_ctrlap(&mut self, val: bool)
Reset from application CTRL-AP detected.
pub const fn set_lockup(&mut self, val: bool)
pub const fn set_lockup(&mut self, val: bool)
Reset from application CPU lockup detected.
pub const fn off(&self) -> bool
pub const fn off(&self) -> bool
Reset due to wakeup from System OFF mode when wakeup is triggered by DETECT signal from GPIO.
pub const fn set_off(&mut self, val: bool)
pub const fn set_off(&mut self, val: bool)
Reset due to wakeup from System OFF mode when wakeup is triggered by DETECT signal from GPIO.
pub const fn lpcomp(&self) -> bool
pub const fn lpcomp(&self) -> bool
Reset due to wakeup from System OFF mode when wakeup is triggered by ANADETECT signal from LPCOMP.
pub const fn set_lpcomp(&mut self, val: bool)
pub const fn set_lpcomp(&mut self, val: bool)
Reset due to wakeup from System OFF mode when wakeup is triggered by ANADETECT signal from LPCOMP.
pub const fn dif(&self) -> bool
pub const fn dif(&self) -> bool
Reset due to wakeup from System OFF mode when wakeup is triggered by entering the Debug Interface mode.
pub const fn set_dif(&mut self, val: bool)
pub const fn set_dif(&mut self, val: bool)
Reset due to wakeup from System OFF mode when wakeup is triggered by entering the Debug Interface mode.
pub const fn nfc(&self) -> bool
pub const fn nfc(&self) -> bool
Reset after wakeup from System OFF mode due to NFC field being detected.
pub const fn set_nfc(&mut self, val: bool)
pub const fn set_nfc(&mut self, val: bool)
Reset after wakeup from System OFF mode due to NFC field being detected.